#
# spec file for package python-PyOgg
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-PyOgg
Version:        0.6.14a1
Release:        3.1
Summary:        Python bindings for Xiphorg's Ogg Vorbis, Opus and FLAC
License:        BSD-3-Clause
URL:            https://github.com/Zuzu-Typ/PyOgg
Source:         https://files.pythonhosted.org/packages/source/P/PyOgg/PyOgg-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libopusenc)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(vorbisfile)
# Automatically get so numbers
Recommends:     %( ls /usr/lib*/libogg.so.*.*.* | sed -r 's/.*(libogg)\.so\.([0-9]*)\..*/\1\2/g' )
Recommends:     libflac
Recommends:     libvorbis
Recommends:     %( ls /usr/lib*/libopus.so.*.*.* | sed -r 's/.*(libopus)\.so\.([0-9]*)\..*/\1\2/g' )
Recommends:     %( ls /usr/lib*/libopusenc.so.*.*.* | sed -r 's/.*(libopusenc)\.so\.([0-9]*)\..*/\1\2/g' )
Recommends:     %( ls /usr/lib*/libopusfile.so.*.*.* | sed -r 's/.*(libopusfile)\.so\.([0-9]*)\..*/\1\2/g' )
Recommends:     %( ls /usr/lib*/libvorbisenc.so.*.*.* | sed -r 's/.*(libvorbisenc)\.so\.([0-9]*)\..*/\1\2/g' )
Recommends:     %( ls /usr/lib*/libvorbisfile.so.*.*.* | sed -r 's/.*(libvorbisfile)\.so\.([0-9]*)\..*/\1\2/g' )
BuildArch:      noarch
%python_subpackages

%description
PyOgg provides bindings for Xiph.org's OGG Vorbis, OGG Opus and FLAC
audio file formats.

%prep
%setup -q -n PyOgg-%{version}
# wrong-file-end-of-line-encoding
sed -i 's/\r$//' README.md README.rst

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.md README.rst
%license COPYING LICENSE
%{python_sitelib}/pyogg
%{python_sitelib}/pyogg-%{version}.dist-info

%changelog
* Tue Mar 25 2025 Steve Kowalik <steven.kowalik@suse.com>
- Lowercase metadata directory name.
* Fri Feb 14 2025 Steve Kowalik <steven.kowalik@suse.com>
- Don't use %%_libdir, it doesn't work for noarch packages
- No more greedy globs in %%files.
- Switch to pyproject macros.
* Sun Aug 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to 0.6.14a1
  * Fixed ope_encoder_write (#27 )
  * Contributions by @mattgwwalker :
  - Added opus_get_version_string() (#23)
  - Added opus_strerror() (#24)
  - Example for opusfile (#25)
  - Opusfile as array (#26)
- update to 0.6.13a1
  * Fixed vorbis_block ( #22 )
* Tue Jan 21 2020 Ludwig Nussel <lnussel@suse.de>
- Recommend shared library package name rather than actual soname.
  Depending on arch, the soname would only pull in the -32bit
  packages.
* Wed Jan 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.6.12a1
  * Fixed library loader
* Tue Sep 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.6.11a1:
  * no upstream changelog
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.6.9a1:
  * no upstream changelog
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.6.7a1:
  * no upstream changelog
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Nov  2 2018 Todd R <toddrme2178@gmail.com>
- Initial version
